@@ -73,7 +73,7 @@ class DataBaseWorker:
             self.schema = self.cred["schema"]
         else:
             self.schema = self.cred["database"]
-        self.logger.info("try to connect...")
+        self.logger.info("try to connect to {}...".format(self.db))
         self.conn = self.engine.connect()
         self.logger.info("connecting is successful")
 
